summaryrefslogtreecommitdiff
path: root/config.h
diff options
context:
space:
mode:
authorDaniel Jones <admin@danieljon.es>2020-05-17 22:53:42 +0930
committerDaniel Jones <admin@danieljon.es>2020-05-17 22:53:42 +0930
commit6f26bf203b485033762b070fc895761923e510f2 (patch)
tree7f331da2b00f8bc87b90327354659e24c2477559 /config.h
parentdf2049aaef95b2b3b6a40689d77c2353eb52c40c (diff)
downloadwebsitegenerator-6f26bf203b485033762b070fc895761923e510f2.tar.gz
websitegenerator-6f26bf203b485033762b070fc895761923e510f2.zip
change how file modification functions work
we use to assume we're definitely editing something in output_dir, now we don't assume that, the caller must tell us so
Diffstat (limited to 'config.h')
-rw-r--r--config.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/config.h b/config.h
index 1404b90..67b497a 100644
--- a/config.h
+++ b/config.h
@@ -25,6 +25,7 @@ enum flag
RSSIMAGES = 1<<2,
PINNED = 1<<3,
GIRLNUMBERS = 1<<4,
+ READMORETAG = 1<<5,
};
struct page
@@ -99,6 +100,7 @@ static const char *direct_output_dir = "posts/direct/";
static const int posts_per_page = 10;
static const int ignore[] = {}; /* ignore these posts */
static const int pinned[] = {112, 107, 104}; /* pinned posts */
+static const char *read_more_tag = "[READMORE]";
/* rss */
static const char *rss_output = "posts/posts.rss";
@@ -123,7 +125,7 @@ static const struct page pages[] = {
{opinions_animepage, NONE},
{opinions_everythingpage, NONE},
{portfoliopage, NONE},
- {postspage, RSS|RSSIMAGES|PINNED|GIRLNUMBERS}, /* flags: RSS feed, RSS images, pinned posts, girl numbers */
+ {postspage, RSS|RSSIMAGES|PINNED|GIRLNUMBERS|READMORETAG}, /* flags: RSS feed, RSS images, pinned posts, girl numbers, read more tag */
};
#endif